﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using JoeScan.JCamNet;

namespace Examples
{
    class Program
    {
        static void Main(string[] args)
        {
            IPAddress baseIpAddress = new IPAddress(new byte[] { 192, 168, 1, 131 });
            Scanner scanner = null;
            try
            {
                scanner = Scanner.Connect(baseIpAddress, 0);    
            }
            catch (Exception e)
            {
                Console.WriteLine("Failed to connect to scanner: {0}, Reason: {1}",
                    baseIpAddress.ToString(), e.Message);
                return;
            }
            TextReader parametersReader;
            using (parametersReader = File.OpenText("param.dat"))
            {
                string parametersString = parametersReader.ReadToEnd();
                try
                {
                    scanner.SetParameters(parametersString, true);
                }
                catch (Exception e)
                {
                    Console.WriteLine("Scanner {0}:{1} did not accept configuration parameters!",
                        scanner.IPAddress.ToString(), scanner.CableID);
                    return;
                }
            }
            // Now we're ready to scan. In this example, we retrieve a fixed number of Profiles from 
            // the scan head. In practice, this would be done in a loop.
            List<Profile> profiles = new List<Profile>();
            for (int i = 0; i < 10; i++)
            {
                try
                {
                    Profile p = scanner.GetProfile();
                    Console.WriteLine("Profile {0}: measured {1} points.", i, p.Count);
                }
                catch(Exception e)
                {
                    Console.WriteLine("Errror retrieving profile from scanner. Exiting.");
                    return;
                }
            }            
        }
    }
}
