﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading;
using JoeScan.JCamNet;

namespace Examples
{
    class Program
    {
        static void Main(string[] args)
        {
            IPAddress baseIpAddress = new IPAddress(new byte[] { 192, 168, 1, 150 });
            Scanner scanner = null;
            try
            {
                scanner = Scanner.Connect(baseIpAddress, 0);
            }
            catch (Exception e)
            {
                Console.WriteLine("Failed to connect to scanner: {0}, Reason: {1}",
                    baseIpAddress.ToString(), e.Message);
                return;
            }
            TextReader parametersReader;
            using (parametersReader = File.OpenText("param.dat"))
            {
                string parametersString = parametersReader.ReadToEnd();
                try
                {
                    scanner.SetParameters(parametersString, true);
                }
                catch (Exception e)
                {
                    Console.WriteLine("Scanner {0}:{1} did not accept configuration parameters!",
                        scanner.IPAddress.ToString(), scanner.CableID);
                    return;
                }
            }
            // Now we're ready to scan. In this example, we scan until we have received ten Profiles. 
            // Be aware that this loop will not end until the ten profiles have been measured, so if you 
            // try this code on a real scan head that for some reason can't measure any points 
            // (blocked view, wrong window settings etc.), the program will appear to hang!
            
            scanner.EnterEncoderSyncMode();
            int profileCount = 0;
            while (profileCount < 10)
            {
                try
                {
                    // In Sync Mode, you must use GetQueuedProfiles() instead of GetProfile()
                    // Here we request one profile at a time. If the encoder hasn't triggered a scan yet,
                    // the returned list is empty.
                    List<Profile> received = scanner.GetQueuedProfiles(1);
                    if (received.Count > 0)
                    {
                        Console.WriteLine("Profile {0}: measured {1} points.",
                            profileCount, received[0].Count);
                        profileCount++;
                    }
                }
                catch (Exception e)
                {
                    Console.WriteLine("Errror retrieving profile from scanner. Exiting.");
                    break;
                }
            }
            // exiting sync mode will clean up all unread profiles from the head
            scanner.ExitSyncMode();
        }
    }
}
